// $Id: logMetaPerformance.java,v 1.2 1998/09/23 06:30:18 oliva Exp $

/* Copyright 1998 Alexandre Oliva <oliva@dcc.unicamp.br>
 *
 * This file is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

import BR.unicamp.Guarana.Guarana;
import BR.unicamp.Guarana.MetaObject;

/**
 * 
 *
 * @author Alexandre Oliva
 * @version $Revision: 1.2 $
 */
public class logMetaPerformance {
    public static void main(final String[] argv) {
	Guarana.reconfigure(performance.statictest.class, null,
			    new MetaLogger(System.out));
	performance.main(argv);
    }
}
